@@ -10,15 +10,15 @@ test_that("rma.peto(), rma.mh(), and rma.glmm() handle outcome1 never occurring
    di <- c(10,10,30,20)
 
    expect_that(rma.peto(ai=ai, bi=bi, ci=ci, di=di), throws_error())
-   
-   res <- rma.mh(measure="OR", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(is.na(res$b), is_true())
-   res <- rma.mh(measure="RR", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(is.na(res$b), is_true())
-   res <- rma.mh(measure="RD", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(unname(res$b), equals(0))
 
-   expect_that(rma.glmm(measure="OR", ai=ai, bi=bi, ci=ci, di=di), throws_error())
+   res <- rma.mh(measure="OR", ai=ai, bi=bi, ci=ci, di=di)
+   expect_true(is.na(res$b))
+   res <- rma.mh(measure="RR", ai=ai, bi=bi, ci=ci, di=di)
+   expect_true(is.na(res$b))
+   res <- rma.mh(measure="RD", ai=ai, bi=bi, ci=ci, di=di)
+   expect_equivalent(res$b, 0)
+
+   expect_error(rma.glmm(measure="OR", ai=ai, bi=bi, ci=ci, di=di))
 
 })
 
@@ -29,15 +29,15 @@ test_that("rma.peto(), rma.mh(), and rma.glmm() handle outcome2 never occurring
    ci <- c(10,10,30,20)
    di <- c(0,0,0,0)
 
-   expect_that(rma.peto(ai=ai, bi=bi, ci=ci, di=di), throws_error())
-   
-   res <- rma.mh(measure="OR", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(is.na(res$b), is_true())
-   res <- rma.mh(measure="RR", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(unname(res$b), equals(0))
-   res <- rma.mh(measure="RD", ai=ai, bi=bi, ci=ci, di=di)
-   expect_that(unname(res$b), equals(0))
+   expect_error(rma.peto(ai=ai, bi=bi, ci=ci, di=di))
 
-   expect_that(rma.glmm(measure="OR", ai=ai, bi=bi, ci=ci, di=di), throws_error())
+   res <- rma.mh(measure="OR", ai=ai, bi=bi, ci=ci, di=di)
+   expect_true(is.na(res$b))
+   res <- rma.mh(measure="RR", ai=ai, bi=bi, ci=ci, di=di)
+   expect_equivalent(res$b, 0)
+   res <- rma.mh(measure="RD", ai=ai, bi=bi, ci=ci, di=di)
+   expect_equivalent(res$b, 0)
+
+   expect_error(rma.glmm(measure="OR", ai=ai, bi=bi, ci=ci, di=di))
 
 })
